### Sample source file for Time Series course
### Yan Liu, 2018/9/28

# install package for seasonal adjustment, for first time user
# install.packages("seasonal")
library(seasonal) # load the package
data(holiday)   # dates of Chinese New Year etc, included in seasonal
cny.ts <- genhol(cny, start = -1, end = 6, center = "calendar") # see manual

# set working directory
wd <- setwd("D:/WHU/Under/TS18/R")

### 李克强指数
data1 <- read.csv("KQI.csv") # read data Keqiang index in csv format
attach(data1) # use data1
date <- as.Date(paste(time, "-01", sep = ""), "%Y-%m-%d") # add day tick to time
plot(date, KQI)
plot(date, KQI, type = "b")
plot(date, KQI, type = "b", pch = 16, lty = 1)
plot(date, KQI, type = "b", pch = 16, lty = 1, col = "blue")
opar <- par(no.readonly = T)
par(mar = c(2,2,3,2))
plot(date, KQI, type = "b", pch = 16, lty = 1, col = "blue", 
     xlab = "", ylab = "", main = "克强指数%")
par(opar)
detach(data1)

mKQI <- mean(KQI)
sKQI <- sd(KQI)
rKQI <- cor(KQI[1:95],KQI[2:96])

### use Tao Zha's China macro time series dataset
data2 <- read.csv("CMTS_quarterly.csv")
attach(data2)
# log transform
opar <- par(no.readonly = T) # save old par specification for plot
par(mfrow = c(1,2))
plot(qtime, NominalGDP, col = "blue",
     xlab = "", ylab = "", 
     main = "GDP", sub = "nominal, quarterly")
plot(qtime, log(NominalGDP), col = "blue",
     xlab = "", ylab = "", 
     main = "log(GDP)", sub = "nominal, quarterly")
par(opar)
# detrending
opar <- par(no.readonly = T) # save old par specification for plot
par(mfcol = c(2,1), mar = c(2,2,2,2))
plot(qtime[2:105], diff(log(NominalGDP)), col = "blue",
     xlab = "", ylab = "", 
     main = "log(GDP): diff")
alpha <- (log(NominalGDP[104]) - log(NominalGDP[1])) / 103
dtlogGDP <- log(NominalGDP) - alpha * c(1:105)
plot(qtime, dtlogGDP, col = "blue",
     xlab = "", ylab = "", 
     main = "log(GDP): detrend")
par(opar)
detach(data2)

### M0原始月度值
data3 <- read.csv("M0.csv")
attach(data3)
date <- as.Date(paste(time, "-01", sep = ""), "%Y-%m-%d")
opar <- par(no.readonly = T) # save old par specification for plot
par(mfcol = c(2,1), mar = c(2,2,2,2))
plot(date, M0, type = "l", col = "blue",
     xlab = "", ylab = "",
     main = "M0")
plot(date, log(M0), type = "l", col = "blue",
     xlab = "", ylab = "",
     main = "log(M0)")
par(opar)
detach(data3)

